import React, { FC } from 'react';
import { SubmitHandler, useForm } from 'react-hook-form';
import { Button } from '@material-ui/core';
import { InputField } from 'components/AuthUser/InputField/InputField';
import { useStyles } from 'components/AuthUser/SignUpForm/useStyles';
import axios from 'axios';
// TODO: Data validation
// TODO: Replace notes with big input field
export const SignUpForm: FC = () => {
  type FormData = {
    user: {
      username: string;
      password: string;
      firstName: string;
      lastName: string;
      email: string;
    };
    phoneNumber: number;
    homeAddress: {
      address: string;
    };
    memberCardIssuer: {
      name: string;
    };
    memberCardNumber: number;
    notes: string;
  };

  const { control, errors, handleSubmit } = useForm<FormData>();

  const onSubmit: SubmitHandler<FormData> = (values: FormData) => {
    axios.post(
      '/api/web/seniors/',
      {
        user: values.user,
        phone_number: values.phoneNumber,
        home_address: values.homeAddress.address,
        member_card_issuer: values.memberCardIssuer,
        notes: values.notes,
      },
      {
        headers: {
          'Content-Type': 'application/json',
        },
      },
    );
  };

  const classes = useStyles();
  return (
    <>
      <form
        className={classes.form}
        onSubmit={handleSubmit(onSubmit)}
        data-testid="Form"
      >
        <InputField
          name="firstName"
          control={control}
          rules={{
            validate: (value: string) => /^[A-Za-z]$/.test(value),
            required: {
              value: true,
              message: 'firstName is not valid',
            },
          }}
          label="First name"
          error={!!errors.user?.firstName}
          errorMessage="Insert firstName"
        />

        <InputField
          name="lastName"
          control={control}
          rules={{
            validate: (value: string) => /^[A-Za-z]$/.test(value),
            required: {
              value: true,
              message: 'lastName is not valid',
            },
          }}
          label="Last name"
          error={!!errors.user?.lastName}
          errorMessage="Insert lastName"
        />

        <InputField
          name="phoneNumber"
          control={control}
          rules={{
            required: {
              value: true,
              message: 'phoneNumber is not valid',
            },
          }}
          label="Phone number"
          error={!!errors.phoneNumber}
          errorMessage="Insert phoneNumber"
        />
        <InputField
          name="memberCardIssuer"
          control={control}
          rules={{
            validate: (value: string) => /^[A-Za-z]$/.test(value),
            required: {
              value: true,
              message: 'memberCardIssuer is not valid',
            },
          }}
          label="Member card issuer"
          error={!!errors.memberCardIssuer?.name}
          errorMessage="Insert memberCardIssuer"
        />

        <InputField
          name="memberCardNumber"
          control={control}
          rules={{
            required: {
              value: true,
              message: 'memberCardNumber is not valid',
            },
          }}
          label="Card number"
          error={!!errors.memberCardNumber}
          errorMessage="Insert memberCardNumber"
        />

        <InputField
          name="address"
          control={control}
          rules={{
            validate: (value: string) => /^[A-Za-z]$/.test(value),
            required: {
              value: true,
              message: 'address is not valid',
            },
          }}
          label="Home address"
          error={!!errors.homeAddress?.address}
          errorMessage="Insert address"
        />

        <InputField
          name="notes"
          control={control}
          label="Notes"
          error={!!errors.notes}
          errorMessage="Insert valid password"
        />

        <InputField
          name="email"
          control={control}
          rules={{
            validate: (value: string) =>
              /^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,}$/i.test(value),
            required: {
              value: true,
              message: 'Email is not valid',
            },
          }}
          label="Email"
          error={!!errors.user?.email}
          errorMessage="Insert email"
        />

        <InputField
          name="password"
          control={control}
          rules={{
            minLength: 8,
            maxLength: 60,
            required: {
              value: true,
              message: 'Insert valid password',
            },
          }}
          label="Password"
          error={!!errors.user?.password}
          errorMessage="Insert valid password"
        />

        <Button
          data-testid="Submit"
          type="submit"
          fullWidth
          variant="contained"
          color="primary"
          className={classes.submit}
        >
          Sign Up
        </Button>
      </form>
    </>
  );
};
